@@ -1,4 +1,5 @@
 from functools import partial
+from typing import Optional
 
 import pandas as pd
 import streamlit as st
@@ -10,11 +11,15 @@ def uploaded_file_to_dataframe(uploaded_file: st.uploaded_file_manager.UploadedF
     return pd.read_csv(uploaded_file, sep="\t" if extension == "tsv" else ",")
 
 
-def hub_dataset_to_dataframe(path: str, name: str, split: str, sample: int, seed: int = 0) -> pd.DataFrame:
+def hub_dataset_to_dataframe(
+    path: str, name: Optional[str], split: Optional[str], sample: int, seed: int = 0, data_files: Optional[str] = None
+) -> pd.DataFrame:
     load_dataset_fn = partial(load_dataset, path=path)
     if name:
         load_dataset_fn = partial(load_dataset_fn, name=name)
     if split:
         load_dataset_fn = partial(load_dataset_fn, split=split)
+    if data_files:
+        load_dataset_fn = partial(load_dataset_fn, data_files=data_files)
     dataset = load_dataset_fn().shuffle(seed=seed)[:sample]
     return pd.DataFrame(dataset)
